from setuptools import setup

setup(name='normbipy',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['normbipy'],
      author=['Mohamed Nabil'],
      zip_safe=False)
